@@ -1,13 +1,15 @@
-from copy import copy
+from copy import copy, deepcopy
 
 import numpy as np
 import xarray as xr
-from sklearn.utils import check_random_state
+import pandas as pd
 from mne.utils import (_check_combine, _check_option, _validate_type,
                        copy_function_doc_to_method_doc, object_size,
-                       sizeof_fmt)
+                       sizeof_fmt, _check_event_id, _ensure_events,
+                       _on_missing, warn, check_random_state)
 
-from mne_connectivity.utils import fill_doc
+from mne_connectivity.utils import (
+    fill_doc, _prepare_xarray_mne_data_structures)
 from mne_connectivity.viz import plot_connectivity_circle
 
 
@@ -36,6 +38,89 @@ class TimeMixin:
 
 
 class EpochMixin:
+    def _init_epochs(self, events, event_id, on_missing='warn') -> None:
+        # Epochs should have the events array that informs user of
+        # sample points at which each Epoch was taken from.
+        # An empty list occurs when NetCDF stores empty arrays.
+        if events is not None and np.array(events).size != 0:
+            events = _ensure_events(events)
+        else:
+            events = np.empty((0, 3))
+
+        event_id = _check_event_id(event_id, events)
+        self.event_id = event_id
+        self.events = events
+
+        # see BaseEpochs init in MNE-Python
+        if events is not None:
+            for key, val in self.event_id.items():
+                if val not in events[:, 2]:
+                    msg = ('No matching events found for %s '
+                           '(event id %i)' % (key, val))
+                    _on_missing(on_missing, msg)
+
+            # ensure metadata matches original events size
+            self.selection = np.arange(len(events))
+            self.events = events
+            del events
+
+            values = list(self.event_id.values())
+            selected = np.where(np.in1d(self.events[:, 2], values))[0]
+
+            self.events = self.events[selected]
+
+    def append(self, epoch_conn):
+        """Append another connectivity structure.
+
+        Parameters
+        ----------
+        epoch_conn : instance of Connectivity
+            The Epoched Connectivity class to append.
+
+        Returns
+        -------
+        self : instance of Connectivity
+            The altered Epoched Connectivity class.
+        """
+        if type(self) != type(epoch_conn):
+            raise ValueError(f'The type of the epoch connectivity to append '
+                             f'is {type(epoch_conn)}, which does not match '
+                             f'{type(self)}.')
+        if hasattr(self, 'times'):
+            if not np.allclose(self.times, epoch_conn.times):
+                raise ValueError('Epochs must have same times')
+        if hasattr(self, 'freqs'):
+            if not np.allclose(self.freqs, epoch_conn.freqs):
+                raise ValueError('Epochs must have same frequencies')
+
+        events = list(deepcopy(self.events))
+        event_id = deepcopy(self.event_id)
+        metadata = copy(self.metadata)
+
+        # compare event_id
+        common_keys = list(set(event_id).intersection(
+            set(epoch_conn.event_id)))
+        for key in common_keys:
+            if not event_id[key] == epoch_conn.event_id[key]:
+                msg = ('event_id values must be the same for identical keys '
+                       'for all concatenated epochs. Key "{}" maps to {} in '
+                       'some epochs and to {} in others.')
+                raise ValueError(msg.format(key, event_id[key],
+                                            epoch_conn.event_id[key]))
+
+        evs = epoch_conn.events.copy()
+        if epoch_conn.n_epochs == 0:
+            warn('Epoch Connectivity object to append was empty.')
+        event_id.update(epoch_conn.event_id)
+        events = np.concatenate((events, evs), axis=0)
+        metadata = pd.concat([epoch_conn.metadata, metadata])
+
+        # now combine the xarray data, altered events and event ID
+        self._obj = xr.concat([self.xarray, epoch_conn.xarray], dim='epochs')
+        self.events = events
+        self.event_id = event_id
+        return self
+
     def combine(self, combine='mean'):
         """Combine connectivity data over epochs.
 
@@ -55,8 +140,15 @@ class EpochMixin:
         """
         from .io import _xarray_to_conn
 
+        if not self.is_epoched:
+            raise RuntimeError('Combine only works over Epoched connectivity. '
+                               f'It does not work with {self}')
+
         fun = _check_combine(combine, valid=('mean', 'median'))
 
+        # get a copy of metadata into attrs as a dictionary
+        self = _prepare_xarray_mne_data_structures(self)
+
         # apply function over the  array
         new_xr = xr.apply_ufunc(fun, self.xarray,
                                 input_core_dims=[['epochs']],
@@ -78,6 +170,34 @@ class EpochMixin:
 
 
 class DynamicMixin:
+    def is_stable(self):
+        companion_mat = self.companion
+        return np.abs(np.linalg.eigvals(companion_mat)).max() < 1.
+
+    def eigvals(self):
+        return np.linalg.eigvals(self.companion)
+
+    @property
+    def companion(self):
+        """Generate block companion matrix.
+
+        Returns the data matrix if the model is VAR(1).
+        """
+        from .vector_ar.utils import _block_companion
+
+        lags = self.attrs.get('lags')
+        data = self.get_data()
+        if lags == 1:
+            return data
+
+        arrs = []
+        for idx in range(self.n_epochs):
+            blocks = _block_companion(
+                [data[idx, ..., jdx]for jdx in range(lags)]
+            )
+            arrs.append(blocks)
+        return arrs
+
     def predict(self, data):
         """Predict samples on actual data.
 
@@ -105,11 +225,10 @@ class DynamicMixin:
             # row are observations, columns are variables
             t = residuals.shape[0]
             sampled_residuals = np.concatenate(
-                np.split(residuals[:, :, model_order:], t, 0),
+                np.split(residuals[:, :, lags:], t, 0),
                 axis=2
             ).squeeze(0)
             rescov = np.cov(sampled_residuals)
-
         """
         if data.ndim < 2 or data.ndim > 3:
             raise ValueError(f'Data passed in must be either 2D or 3D. '
@@ -129,35 +248,36 @@ class DynamicMixin:
         var_model = self.get_data(output='dense')
 
         # get the model order
-        model_order = self.attrs.get('model_order')
+        lags = self.attrs.get('lags')
 
         # predict the data by applying forward model
         predicted_data = np.zeros(data.shape)
         # which takes less loop iterations
-        if n_epochs > n_times - model_order:
-            for idx in range(1, model_order + 1):
-                for jdx in range(model_order, n_times):
+        if n_epochs > n_times - lags:
+            for idx in range(1, lags + 1):
+                for jdx in range(lags, n_times):
                     if self.is_epoched:
-                        bp = var_model[jdx, :, (idx - 1)::model_order]
+                        bp = var_model[jdx, :, (idx - 1)::lags]
                     else:
-                        bp = var_model[:, (idx - 1)::model_order]
+                        bp = var_model[:, (idx - 1)::lags]
                     predicted_data[:, :,
                                    jdx] += np.dot(data[:, :, jdx - idx], bp.T)
         else:
-            for idx in range(1, model_order + 1):
+            for idx in range(1, lags + 1):
                 for jdx in range(n_epochs):
                     if self.is_epoched:
-                        bp = var_model[jdx, :, (idx - 1)::model_order]
+                        bp = var_model[jdx, :, (idx - 1)::lags]
                     else:
-                        bp = var_model[:, (idx - 1)::model_order]
-                    predicted_data[jdx, :, model_order:] += \
+                        bp = var_model[:, (idx - 1)::lags]
+                    predicted_data[jdx, :, lags:] += \
                         np.dot(
                             bp,
-                            data[jdx, :, (model_order - idx):(n_times - idx)]
+                            data[jdx, :, (lags - idx):(n_times - idx)]
                     )
 
         return predicted_data
 
+    @fill_doc
     def simulate(self, n_samples, noise_func=None, random_state=None):
         """Simulate vector autoregressive (VAR) model.
 
@@ -167,10 +287,11 @@ class DynamicMixin:
         ----------
         n_samples : int
             Number of samples to generate.
-        noisefunc : func, optional
+        noise_func : func, optional
             This function is used to create the generating noise process. If
             set to None, Gaussian white noise with zero mean and unit variance
             is used.
+        %(random_state)s
 
         Returns
         -------
@@ -182,7 +303,7 @@ class DynamicMixin:
             var_model = var_model.mean(axis=0)
 
         n_nodes = self.n_nodes
-        model_order = self.attrs.get('model_order')
+        lags = self.attrs.get('lags')
 
         # set noise function
         if noise_func is None:
@@ -192,35 +313,39 @@ class DynamicMixin:
 
                 return rng.normal(size=(1, n_nodes))
 
-        n = n_samples + 10 * model_order
+        n = n_samples + 10 * lags
 
         # simulated data
         data = np.zeros((n, n_nodes))
         res = np.zeros((n, n_nodes))
 
-        for jdx in range(model_order):
+        for jdx in range(lags):
             e = noise_func()
             res[jdx, :] = e
             data[jdx, :] = e
-        for jdx in range(model_order, n):
+        for jdx in range(lags, n):
             e = noise_func()
             res[jdx, :] = e
             data[jdx, :] = e
-            for idx in range(1, model_order + 1):
+            for idx in range(1, lags + 1):
                 data[jdx, :] += \
-                    var_model[:, (idx - 1)::model_order].dot(
+                    var_model[:, (idx - 1)::lags].dot(
                         data[jdx - idx, :]
                 )
 
-        # self.residuals = res[10 * model_order:, :, :].T
+        # self.residuals = res[10 * lags:, :, :].T
         # self.rescov = sp.cov(cat_trials(self.residuals).T, rowvar=False)
-        return data[10 * model_order:, :].transpose()
+        return data[10 * lags:, :].transpose()
 
 
 @fill_doc
-class _Connectivity(DynamicMixin):
+class BaseConnectivity(DynamicMixin, EpochMixin):
     """Base class for connectivity data.
 
+    This class should not be instantiated directly, but should be used
+    to do type-checking. All connectivity classes will be returned from
+    corresponding connectivity computing functions.
+
     Connectivity data is anything that represents "connections"
     between nodes as a (N, N) array. It can be symmetric, or
     asymmetric (if it is symmetric, storage optimization will
@@ -233,12 +358,12 @@ class _Connectivity(DynamicMixin):
     %(indices)s
     %(method)s
     %(n_nodes)s
-    kwargs : dict
-        Extra connectivity parameters. These may include
-        ``freqs`` for spectral connectivity, and/or
-        ``times`` for connectivity over time. In addition,
-        these may include extra parameters that are stored
-        as xarray ``attrs``.
+    %(events)s
+    %(event_id)s
+    metadata : instance of pandas.DataFrame | None
+        The metadata data frame that would come from the :class:`mne.Epochs`
+        class. See :class:`mne.Epochs` docstring for details.
+    %(connectivity_kwargs)s
 
     Notes
     -----
@@ -268,7 +393,8 @@ class _Connectivity(DynamicMixin):
     is_epoched = False
 
     def __init__(self, data, names, indices, method,
-                 n_nodes, **kwargs):
+                 n_nodes, events=None, event_id=None,
+                 metadata=None, **kwargs):
 
         if isinstance(indices, str) and \
                 indices not in ['all', 'symmetric']:
@@ -277,14 +403,23 @@ class _Connectivity(DynamicMixin):
                              f'should be a list of tuples. '
                              f'It cannot be {indices}.')
 
+        # prepare metadata pandas dataframe and ensure metadata is a Pandas
+        # DataFrame object
+        if metadata is None:
+            metadata = pd.DataFrame(dtype='float64')
+        self.metadata = metadata
+
         # check the incoming data structure
         self._check_data_consistency(data, indices=indices, n_nodes=n_nodes)
         self._prepare_xarray(data, names=names, indices=indices,
-                             n_nodes=n_nodes, method=method, **kwargs)
+                             n_nodes=n_nodes, method=method, events=events,
+                             event_id=event_id, **kwargs)
 
     def __repr__(self) -> str:
         r = f'<{self.__class__.__name__} | '
 
+        if self.n_epochs is not None:
+            r += f"n_epochs : {self.n_epochs}, "
         if 'freqs' in self.dims:
             r += "freq : [%f, %f], " % (self.freqs[0], self.freqs[-1])
         if 'times' in self.dims:
@@ -301,23 +436,18 @@ class _Connectivity(DynamicMixin):
         # account for epoch data structures
         if self.is_epoched:
             start_idx = 1
-            self.n_epochs = data.shape[0]
         else:
-            self.n_epochs = None
             start_idx = 0
         self.n_estimated_nodes = data.shape[start_idx]
 
     def _prepare_xarray(self, data, names, indices, n_nodes, method,
-                        **kwargs):
-        """Prepare xarray data structure.
+                        events, event_id, **kwargs):
+        """Prepare xarray data structure."""
+        # generate events and event_id that originate from Epochs class
+        # which stores the windows of Raw that were used to generate
+        # the corresponding connectivity data
+        self._init_epochs(events, event_id, on_missing='warn')
 
-        Parameters
-        ----------
-        data : [type]
-            [description]
-        names : [type]
-            [description]
-        """
         # set node names
         if names is None:
             names = list(map(str, range(n_nodes)))
@@ -358,6 +488,8 @@ class _Connectivity(DynamicMixin):
         kwargs['method'] = method
         kwargs['indices'] = indices
         kwargs['n_nodes'] = n_nodes
+        kwargs['events'] = self.events
+        # kwargs['event_id'] = self.event_id
 
         # create xarray object
         xarray_obj = xr.DataArray(
@@ -421,6 +553,21 @@ class _Connectivity(DynamicMixin):
                                  f'But there should be {expected_len} '
                                  f'estimated connections.')
 
+    def copy(self):
+        return deepcopy(self)
+
+    def get_epoch_annotations(self):
+        pass
+
+    @property
+    def n_epochs(self):
+        """The number of epochs the connectivity data varies over."""
+        if self.is_epoched:
+            n_epochs = self._data.shape[0]
+        else:
+            n_epochs = None
+        return n_epochs
+
     @property
     def _data(self):
         """Numpy array of connectivity data."""
@@ -492,7 +639,9 @@ class _Connectivity(DynamicMixin):
     def n_epochs_used(self):
         """Number of epochs used in computation of connectivity.
 
-        Can be 'None', if there was no epochs used.
+        Can be 'None', if there was no epochs used. This is
+        equivalent to the number of epochs, if there is no
+        combining of epochs.
         """
         return self.attrs.get('n_epochs_used')
 
@@ -500,8 +649,11 @@ class _Connectivity(DynamicMixin):
     def _size(self):
         """Estimate the object size."""
         size = 0
-        size += object_size(self.get_data())
+        size += object_size(self._data)
         size += object_size(self.attrs)
+
+        # if self.metadata is not None:
+        #     size += self.metadata.memory_usage(index=True).sum()
         return size
 
     def get_data(self, output='compact'):
@@ -541,9 +693,8 @@ class _Connectivity(DynamicMixin):
 
             # handle the case where model order is defined in VAR connectivity
             # and thus appends the connectivity matrices side by side, so the
-            # shape is N x N * model_order
-            model_order = self.attrs.get('model_order', 1)
-            new_shape.extend([self.n_nodes * model_order, self.n_nodes])
+            # shape is N x N * lags
+            new_shape.extend([self.n_nodes, self.n_nodes])
             if 'freqs' in self.dims:
                 new_shape.append(len(self.coords['freqs']))
             if 'times' in self.dims:
@@ -658,6 +809,9 @@ class _Connectivity(DynamicMixin):
         # save the name of the connectivity structure
         self.attrs['data_structure'] = str(self.__class__.__name__)
 
+        # get a copy of metadata into attrs as a dictionary
+        self = _prepare_xarray_mne_data_structures(self)
+
         # netCDF does not support 'None'
         # so map these to 'n/a'
         for key, val in self.attrs.items():
@@ -666,15 +820,22 @@ class _Connectivity(DynamicMixin):
 
         # save as a netCDF file
         # note this requires the netcdf4 python library
-        self.xarray.to_netcdf(fname, mode='w', format='NETCDF4',
-                              engine='netcdf4')
+        # and h5netcdf library.
+        # The engine specified requires the ability to save
+        # complex data types, which was not natively supported
+        # in xarray. Therefore, h5netcdf is the only engine
+        # to support that feature at this moment.
+        self.xarray.to_netcdf(fname, mode='w',
+                              format='NETCDF4',
+                              engine='h5netcdf',
+                              invalid_netcdf=True)
 
         # re-set old attributes
         self.xarray.attrs = old_attrs
 
 
 @fill_doc
-class SpectralConnectivity(_Connectivity, SpectralMixin):
+class SpectralConnectivity(BaseConnectivity, SpectralMixin):
     """Spectral connectivity class.
 
     This class stores connectivity data that varies over
@@ -691,24 +852,26 @@ class SpectralConnectivity(_Connectivity, SpectralMixin):
     %(method)s
     %(spec_method)s
     %(n_epochs_used)s
+    %(connectivity_kwargs)s
 
     See Also
     --------
-    mne_connectivity.spectral_connectivity
+    mne_connectivity.spectral_connectivity_epochs
     """
     expected_n_dim = 2
 
     def __init__(self, data, freqs, n_nodes, names=None,
                  indices='all', method=None, spec_method=None,
                  n_epochs_used=None, **kwargs):
-        super().__init__(data, names=names, method=method,
-                         indices=indices, n_nodes=n_nodes,
-                         freqs=freqs, spec_method=spec_method,
-                         n_epochs_used=n_epochs_used, **kwargs)
+        super(SpectralConnectivity, self).__init__(
+            data, names=names, method=method,
+            indices=indices, n_nodes=n_nodes,
+            freqs=freqs, spec_method=spec_method,
+            n_epochs_used=n_epochs_used, **kwargs)
 
 
 @fill_doc
-class TemporalConnectivity(_Connectivity, TimeMixin):
+class TemporalConnectivity(BaseConnectivity, TimeMixin):
     """Temporal connectivity class.
 
     This is an array of shape (n_connections, n_times),
@@ -726,6 +889,7 @@ class TemporalConnectivity(_Connectivity, TimeMixin):
     %(indices)s
     %(method)s
     %(n_epochs_used)s
+    %(connectivity_kwargs)s
 
     Notes
     -----
@@ -740,14 +904,15 @@ class TemporalConnectivity(_Connectivity, TimeMixin):
 
     def __init__(self, data, times, n_nodes, names=None, indices='all',
                  method=None, n_epochs_used=None, **kwargs):
-        super().__init__(data, names=names, method=method,
-                         n_nodes=n_nodes, indices=indices,
-                         times=times, n_epochs_used=n_epochs_used,
-                         **kwargs)
+        super(TemporalConnectivity, self).__init__(
+            data, names=names, method=method,
+            n_nodes=n_nodes, indices=indices,
+            times=times, n_epochs_used=n_epochs_used,
+            **kwargs)
 
 
 @fill_doc
-class SpectroTemporalConnectivity(_Connectivity, SpectralMixin, TimeMixin):
+class SpectroTemporalConnectivity(BaseConnectivity, SpectralMixin, TimeMixin):
     """Spectrotemporal connectivity class.
 
     This class stores connectivity data that varies over both frequency
@@ -769,19 +934,21 @@ class SpectroTemporalConnectivity(_Connectivity, SpectralMixin, TimeMixin):
     %(method)s
     %(spec_method)s
     %(n_epochs_used)s
+    %(connectivity_kwargs)s
     """
 
     def __init__(self, data, freqs, times, n_nodes, names=None,
                  indices='all', method=None,
                  spec_method=None, n_epochs_used=None, **kwargs):
-        super().__init__(data, names=names, method=method, indices=indices,
-                         n_nodes=n_nodes, freqs=freqs,
-                         spec_method=spec_method, times=times,
-                         n_epochs_used=n_epochs_used, **kwargs)
+        super(SpectroTemporalConnectivity, self).__init__(
+            data, names=names, method=method, indices=indices,
+            n_nodes=n_nodes, freqs=freqs,
+            spec_method=spec_method, times=times,
+            n_epochs_used=n_epochs_used, **kwargs)
 
 
 @fill_doc
-class EpochSpectralConnectivity(SpectralConnectivity, EpochMixin):
+class EpochSpectralConnectivity(SpectralConnectivity):
     """Spectral connectivity class over Epochs.
 
     This is an array of shape (n_epochs, n_connections, n_freqs),
@@ -797,6 +964,7 @@ class EpochSpectralConnectivity(SpectralConnectivity, EpochMixin):
     %(indices)s
     %(method)s
     %(spec_method)s
+    %(connectivity_kwargs)s
     """
     # whether or not the connectivity occurs over epochs
     is_epoched = True
@@ -804,14 +972,14 @@ class EpochSpectralConnectivity(SpectralConnectivity, EpochMixin):
     def __init__(self, data, freqs, n_nodes, names=None,
                  indices='all', method=None,
                  spec_method=None, **kwargs):
-        super().__init__(
+        super(EpochSpectralConnectivity, self).__init__(
             data, freqs=freqs, names=names, indices=indices,
             n_nodes=n_nodes, method=method,
             spec_method=spec_method, **kwargs)
 
 
 @fill_doc
-class EpochTemporalConnectivity(TemporalConnectivity, EpochMixin):
+class EpochTemporalConnectivity(TemporalConnectivity):
     """Temporal connectivity class over Epochs.
 
     This is an array of shape (n_epochs, n_connections, n_times),
@@ -826,21 +994,21 @@ class EpochTemporalConnectivity(TemporalConnectivity, EpochMixin):
     %(names)s
     %(indices)s
     %(method)s
+    %(connectivity_kwargs)s
     """
     # whether or not the connectivity occurs over epochs
     is_epoched = True
 
     def __init__(self, data, times, n_nodes, names=None,
                  indices='all', method=None, **kwargs):
-        super().__init__(data, times=times, names=names,
-                         indices=indices, n_nodes=n_nodes,
-                         method=method, **kwargs)
+        super(EpochTemporalConnectivity, self).__init__(
+            data, times=times, names=names,
+            indices=indices, n_nodes=n_nodes,
+            method=method, **kwargs)
 
 
 @fill_doc
-class EpochSpectroTemporalConnectivity(
-    SpectroTemporalConnectivity, EpochMixin
-):
+class EpochSpectroTemporalConnectivity(SpectroTemporalConnectivity):
     """Spectrotemporal connectivity class over Epochs.
 
     This is an array of shape (n_epochs, n_connections, n_freqs, n_times),
@@ -857,6 +1025,7 @@ class EpochSpectroTemporalConnectivity(
     %(indices)s
     %(method)s
     %(spec_method)s
+    %(connectivity_kwargs)s
     """
     # whether or not the connectivity occurs over epochs
     is_epoched = True
@@ -864,14 +1033,14 @@ class EpochSpectroTemporalConnectivity(
     def __init__(self, data, freqs, times, n_nodes,
                  names=None, indices='all', method=None,
                  spec_method=None, **kwargs):
-        super().__init__(
+        super(EpochSpectroTemporalConnectivity, self).__init__(
             data, names=names, freqs=freqs, times=times, indices=indices,
             n_nodes=n_nodes, method=method, spec_method=spec_method,
             **kwargs)
 
 
 @fill_doc
-class Connectivity(_Connectivity, EpochMixin):
+class Connectivity(BaseConnectivity):
     """Connectivity class without frequency or time component.
 
     This is an array of shape (n_connections,),
@@ -886,6 +1055,7 @@ class Connectivity(_Connectivity, EpochMixin):
     %(indices)s
     %(method)s
     %(n_epochs_used)s
+    %(connectivity_kwargs)s
 
     See Also
     --------
@@ -895,21 +1065,20 @@ class Connectivity(_Connectivity, EpochMixin):
 
     def __init__(self, data, n_nodes, names=None, indices='all',
                  method=None, n_epochs_used=None, **kwargs):
-        super().__init__(data, names=names, method=method,
-                         n_nodes=n_nodes, indices=indices,
-                         n_epochs_used=n_epochs_used,
-                         **kwargs)
+        super(Connectivity, self).__init__(data, names=names, method=method,
+                                           n_nodes=n_nodes, indices=indices,
+                                           n_epochs_used=n_epochs_used,
+                                           **kwargs)
 
 
 @fill_doc
-class EpochConnectivity(_Connectivity, EpochMixin):
+class EpochConnectivity(BaseConnectivity):
     """Epoch connectivity class.
 
     This is an array of shape (n_epochs, n_connections),
     or (n_epochs, n_nodes, n_nodes). This describes how
     connectivity varies for different epochs.
 
-
     Parameters
     ----------
     %(data)s
@@ -918,6 +1087,7 @@ class EpochConnectivity(_Connectivity, EpochMixin):
     %(indices)s
     %(method)s
     %(n_epochs_used)s
+    %(connectivity_kwargs)s
 
     See Also
     --------
@@ -930,7 +1100,8 @@ class EpochConnectivity(_Connectivity, EpochMixin):
 
     def __init__(self, data, n_nodes, names=None, indices='all',
                  method=None, n_epochs_used=None, **kwargs):
-        super().__init__(data, names=names, method=method,
-                         n_nodes=n_nodes, indices=indices,
-                         n_epochs_used=n_epochs_used,
-                         **kwargs)
+        super(EpochConnectivity, self).__init__(
+            data, names=names, method=method,
+            n_nodes=n_nodes, indices=indices,
+            n_epochs_used=n_epochs_used,
+            **kwargs)
