@@ -1,4 +1,4 @@
 """Visualization routines."""
 
 from ._3d import plot_sensors_connectivity
-from .circle import circular_layout, plot_connectivity_circle
+from .circle import plot_connectivity_circle
